@@ -9,7 +9,7 @@ require DynaLoader;
 use vars qw($VERSION @ISA $__import @preload $pid);
 @ISA = qw(DynaLoader);
 sub dl_load_flags { 0x00 }
-$VERSION = '1.75';
+$VERSION = '1.76';
 $pid = $$;
 bootstrap Prima $VERSION;
 unless ( UNIVERSAL::can('Prima', 'init')) {
@@ -138,7 +138,7 @@ Prima - a Perl graphic toolkit
 		onClick  => sub { $::application-> close },
 	);
 
-	run Prima;
+	Prima->run;
 
 See more screenshots at L<http://prima.eu.org/big-picture>.
 
@@ -209,7 +209,7 @@ shorter by using the following scheme:
 
 Another basic issue is the event loop, which is called by
 
-	run Prima;
+	Prima->run;
 
 code and requires a C<Prima::Application> object to be created beforehand.
 Invoking the C<Prima::Application> standard module is one of the possible ways
@@ -338,6 +338,10 @@ L<Prima::Widget> - window management
 
 =item *
 
+L<Prima::Widget::grid> - Tk::grid geometry manager
+
+=item *
+
 L<Prima::Widget::pack> - Tk::pack geometry manager
 
 =item *
@@ -579,7 +583,7 @@ standard Prima documentation viewer C<podview> ( see File/Run/prima-class ).
 Copyright 1997-2003 The Protein Laboratory, University of Copenhagen. All
 rights reserved.
 
-Copyright 2004-2024 Dmitry Karasik. All rights reserved.
+Copyright 2004-2025 Dmitry Karasik. All rights reserved.
 
 This program is distributed under the BSD License.
 
