@@ -1012,27 +1012,6 @@ sub read_jpeg
 	}
 }
 
-sub read_jxl
-{
-	my ($class, $i, %opt) = @_;
-
-	my $data;
-	return (undef, "no jxl exif data") unless
-		($i->codec // '') eq 'JXL' and
-		exists $i->{extras}->{exif} and
-		$data = $i->{extras}->{exif};
-
-	if ( $data =~ /^.{4}Exif/) {
-		$data = substr($data,4);
-	} elsif ( $data =~ /^\x{00}\x{00}/ ) {
-		$data = 'Exif'.substr($data,2);
-	} else {
-		return (undef, "no jxl exif data");
-	}
-
-	return parse_datum( $class, $data, %opt);
-}
-
 sub parse_datum
 {
 	my ( $class, $data, %opt ) = @_;
@@ -1064,8 +1043,6 @@ sub read_extras
 	my $c = $i->codec // '';
 	if ( $c eq 'JPEG') {
 		return $class->read_jpeg($i, %opt);
-	} elsif ( $c eq 'JXL') {
-		return $class->read_jxl($i, %opt);
 	} else {
 		return (undef, "not supported");
 	}
@@ -1118,19 +1095,6 @@ sub write_jpeg
 	return 1;
 }
 
-sub write_jxl
-{
-	my ($class, $i, $data) = @_;
-
-	return undef, "jpeg-xl is not supported" unless $i->codec('JXL');
-
-	my ($compiled, $error) = $class->compile($data);
-	return (undef, $error) if !defined $compiled;
-	$compiled = substr($compiled,4);
-	$i->{extras}->{exif} = $compiled;
-	return 1;
-}
-
 sub supported_ifds { qw(image photo gpsinfo) }
 
 sub revtags
@@ -1161,8 +1125,6 @@ sub write_extras
 
 	if ( $c eq 'JPEG' ) {
 		return $class->write_jpeg($i, $data);
-	} elsif ( $c eq 'JXL') {
-		return $class->write_jxl($i, $data);
 	} else {
 		return (undef, "not supported");
 	}
@@ -1179,7 +1141,8 @@ Prima::Image::Exif - manipulate Exif records
 =head1 DESCRIPTION
 
 The module allows to parse and create Exif records. The records
-could be read from JPEG and JXL files, and prepared to be stored there.
+could be read from JPEG files, and stored in these using the
+extra appdata hash field.
 
 =head1 SYNOPSIS
 
