@@ -14,20 +14,11 @@ sub insert_buttons
 	my ( $dlg, $buttons, $extras) = @_;
 	my ( $left, $right) = ( 10, 425);
 	my $i;
-	my @bConsts =  (
-		mb::Help, mb::Cancel, mb::Ignore, mb::Retry, mb::Abort, mb::No, mb::Yes, mb::Ok
-	);
-	my @bTexts  = qw(
-		~Help    ~Cancel     ~Ignore     ~Retry     ~Abort     ~No     ~Yes     ~OK
-	);
+	my @bConsts =  ( mb::Ok, mb::Yes, mb::No, mb::Abort, mb::Retry, mb::Ignore, mb::Cancel, mb::Help);
+	my @bTexts  = qw(   ~OK     ~Yes     ~No     ~Abort     ~Retry     ~Ignore     ~Cancel     ~Help);
 	my $helpTopic = defined $$extras{helpTopic} ? $$extras{helpTopic} : 'Prima';
 	my $defButton = defined $$extras{defButton} ? $$extras{defButton} : 0xFF;
-	my $fresh;
-	my $freshFirst;
-
-	my $dir = 0; # set to 1 for reverse direction of buttons
-	@bConsts = reverse @bConsts unless $dir;
-	@bTexts  = reverse @bTexts  unless $dir;
+	my @ret;
 
 	my $btns = 0;
 	for ( $i = 0; $i < scalar @bConsts; $i++) {
@@ -47,28 +38,23 @@ sub insert_buttons
 		);
 
 		$defButton = 0 if $bConsts[$i] & $defButton;
-		$dir ? ( $hpr{right} = $right, $hpr{tabOrder} = 0) : ( $hpr{left} = $left);
+		$hpr{left} = $left;
 
 		if ( $bConsts[$i] == mb::Help) {
 			$hpr{onClick} = sub {
 				$::application-> open_help( $helpTopic);
 			};
-			unless ( $dir) {
-				$hpr{right} = 425;
-				delete $hpr{left};
-			}
+			$hpr{right} = 425;
+			delete $hpr{left};
 		} else {
 			$hpr{modalResult} = $bConsts[$i];
 		}
-		$fresh = $dlg-> insert( Button => %hpr, %epr);
-		$freshFirst = $fresh unless $freshFirst;
-		my $w = $fresh-> width + 10;
+		push @ret, $dlg-> insert( Button => %hpr, %epr);
 		$right -= 106;
 		$left  += 106;
 		last if ++$btns > 3;
 	}
-	$fresh = $freshFirst unless $dir;
-	return $fresh;
+	return @ret;
 }
 
 sub message_box
@@ -117,31 +103,40 @@ sub message_box
 		onExecute     => sub {
 			Prima::Utils::beep( $options) if $options && !$nosound;
 		},
+		%{$extras->{dialog} // {}},
 	);
 
-	my $fresh = insert_buttons( $dlg, $buttons, $extras);
+	my @btns = insert_buttons( $dlg, $buttons, $extras);
 
 	$dlg-> scaleChildren(0);
 
 	my $iconRight = 0;
-	if ( $icon and ($icon = Prima::StdBitmap::icon( $icon))) {
+	if ( defined $extras->{icon}) {
+		$icon = $extras->{icon};
+	} elsif ( $icon ) {
+		$icon = Prima::StdBitmap::icon( $icon);
+	}
+	if ($icon) {
 		my $iconView = $dlg-> insert( Widget =>
 			growMode       => gm::GrowHiY,
 			left           => 20,
 			width          => $icon-> width,
 			top            => $dlg-> height - 10,
-			bottom         => $fresh-> height + 20,
+			bottom         => $btns[0]-> height + 20,
 			ownerBackColor => 1,
 			onPaint        => sub {
 				my $self = $_[1];
 				$self-> clear;
 				$self-> put_image(0, ($self->height - $icon->height)/2, $icon);
-			},
+			}
 		);
 		$iconRight = $iconView-> right;
 	}
 
-	my $label = $dlg-> insert( 'Label' , text => $text );
+	my $label = $dlg-> insert( 'Label' ,
+		text => $text,
+		%{$extras->{label} // {}},
+	);
 	unless ( defined $extras->{wordWrap} ) {
 		# can the text fit in a quarter of the screen?
 		my @as    = map { $_ / 2 } $::application->size;
@@ -152,11 +147,22 @@ sub message_box
 		$extras->{wordWrap} = $lc <= $gl;
 	}
 
+	if ( $extras->{wordWrap} && $extras->{compact} && @btns) {
+		my @sz = $dlg->sizeMin;
+		$sz[0] = $btns[-1]->right + $btns[0]->left;
+		$sz[0] += $btns[0]->right if @btns < 2;
+		$dlg->sizeMin(@sz);
+		$dlg->width($sz[0]);
+		if ( ( my $diff = ($sz[0] - $btns[-1]->right - $btns[0]->left) / 2 ) > 0 ) {
+			$_->left( $_->left + $diff ) for @btns;
+		}
+	}
+
 	my %geom = (
 		left          => $iconRight + 15,
 		right         => $dlg-> width  - 10,
 		top           => $dlg-> height - 10,
-		bottom        => $fresh-> height + 20,
+		bottom        => $btns[0]-> height + 20,
 		growMode      => gm::Client,
 	);
 	my $scroller;
@@ -179,7 +185,7 @@ sub message_box
 	}
 
 	# expand the dialog
-	my $gl = int(( $dlg-> height - 10 - $fresh-> height - 20) / $label-> font-> height);
+	my $gl = int(( $dlg-> height - 10 - $btns[0]-> height - 20) / $label-> font-> height);
 	my $lc = scalar @{ $label-> text_wrap(
 		$text,
 		$label-> width,
@@ -224,15 +230,17 @@ sub input_box
 		scaleChildren => 1,
 		visible       => 0,
 		text          => $title,
+		%{$extras->{dialog} // {}},
 	);
 
-	my $fresh = insert_buttons( $dlg, $buttons, $extras);
+	insert_buttons( $dlg, $buttons, $extras);
 
 	$dlg-> insert( Label =>
 		origin        => [ 10, 82],
 		size          => [ 415, 16],
 		text          => $text,
 		showAccelChar => 1,
+		%{$extras->{label} // {}},
 	);
 
 	my $input = $dlg-> insert( InputLine =>
@@ -240,7 +248,7 @@ sub input_box
 		origin        => [ 10, 56],
 		text          => $string,
 		current       => 1,
-		defined($extras-> {inputLine}) ? %{$extras-> {inputLine}} : (),
+		%{$extras->{input} // {}},
 	);
 
 	my @ret = ( $dlg-> execute, $input-> text);
@@ -318,7 +326,7 @@ in the dialog.
 
 The PROFILE parameter is a hash, that contains customization parameters for the
 buttons and the input line. To access the input line parameters the
-C<inputLine> hash key is used.  See L<Buttons and profiles> for more
+C<input> hash key is used.  See L<Buttons and profiles> for more
 information on BUTTONS and PROFILES.
 
 Returns different results depending on the call context.  In the array
@@ -389,28 +397,15 @@ customizations:
 
 =over
 
-=item defButton INTEGER
+=item compact BOOLEAN = 0
 
-Selects the default button in the dialog, i.e. the button that reacts on the
-return key. Its value must be to an C<mb::> constant of the desired button. If
-this option is not set, the leftmost button is selected as the default.
+If 1, the message box width is shrunken so that there's no empty
+space on to the right. Also, in case there is only one button, it is centered.
 
-=item font FONT
+The option ignored if C<wordWrap> is unset, or the text
+is too big to fit to the dialog window without scrolling.
 
-The message boxes use C<Application.get_message_font>, but the C<font> option
-can override that.
-
-=item helpTopic TOPIC
-
-Selects the help TOPIC invoked in the help viewer window if the C<mb::Help>
-button is pressed by the user. If this option is not set, L<Prima> is
-displayed.
-
-=item inputLine HASH
-
-Only for C<input_box>.
-
-Contains the profile hash passed to the input line as creation parameters.
+Actual only for the message box, not for the input box.
 
 =item buttons HASH
 
@@ -432,6 +427,43 @@ If it is not desired that the dialog must be closed when the user presses a
 button, its C<::modalResult> property ( see L<Prima::Buttons> ) must be reset
 to 0.
 
+=item defButton INTEGER
+
+Selects the default button in the dialog, i.e. the button that reacts on the
+return key. Its value must be to an C<mb::> constant of the desired button. If
+this option is not set, the leftmost button is selected as the default.
+
+=item dialog HASH
+
+An optional hash override the dialog properties
+
+=item font FONT
+
+The message boxes use C<Application.get_message_font>, but the C<font> option
+can override that.
+
+=item helpTopic TOPIC
+
+Selects the help TOPIC invoked in the help viewer window if the C<mb::Help>
+button is pressed by the user. If this option is not set, L<Prima> is
+displayed.
+
+=item icon IMAGE
+
+Only for C<message_box>.
+
+Contains the icon to display 
+
+=item input HASH
+
+Only for C<input_box>.
+
+Contains the profile hash passed to the input line as creation parameters.
+
+=item label HASH
+
+Contains the profile hash passed to the label as creation parameters.
+
 =item owner WINDOW
 
 If set, the dialog owner is set to WINDOW, otherwise to C<$::main_window>.
