@@ -75,33 +75,6 @@ is_var_id_name( char * name)
 	return ret;
 }
 
-void
-AbstractMenu_dispose_menu( Handle self, void * menu)
-{
-	PMenuItemReg m = ( PMenuItemReg) menu;
-	if  ( m == NULL) return;
-	free( m-> text);
-	free( m-> accel);
-	free( m-> variable);
-	free( m-> perlSub);
-	if ( m-> code) sv_free( m-> code);
-	if ( m-> options) sv_free( m-> options);
-	if ( m-> bitmap) {
-		if ( PObject( m-> bitmap)-> stage < csDead)
-			SvREFCNT_dec( SvRV(( PObject( m-> bitmap))-> mate));
-		unprotect_object( m-> bitmap);
-	}
-	if ( m-> icon) {
-		if ( PObject( m-> icon)-> stage < csDead)
-			SvREFCNT_dec( SvRV(( PObject( m-> icon))-> mate));
-		unprotect_object( m-> icon);
-	}
-	my-> dispose_menu( self, m-> next);
-	my-> dispose_menu( self, m-> down);
-	free( m);
-}
-
-
 static Bool
 register_image(Handle c_object)
 {
@@ -117,6 +90,41 @@ register_image(Handle c_object)
 	return true;
 }
 
+static void
+unregister_image(Handle c_object)
+{
+	if ( PObject( c_object)-> stage < csDead)
+		SvREFCNT_dec( SvRV(( PObject( c_object))-> mate));
+	unprotect_object( c_object);
+}
+
+void
+AbstractMenu_dispose_menu( Handle self, void * menu)
+{
+	PMenuItemReg m = ( PMenuItemReg) menu;
+	if  ( m == NULL) return;
+	free( m-> text);
+	free( m-> accel);
+	free( m-> variable);
+	free( m-> perlSub);
+	if ( m-> code)
+		sv_free( m-> code);
+	if ( m-> hint)
+		sv_free( m-> hint);
+	if ( m-> onMeasure)
+		sv_free( m-> onMeasure);
+	if ( m-> onPaint)
+		sv_free( m-> onPaint);
+	if ( m-> bitmap)
+		unregister_image( m-> bitmap );
+	if ( m-> icon)
+		unregister_image( m-> icon );
+	my-> dispose_menu( self, m-> next);
+	my-> dispose_menu( self, m-> down);
+	free( m);
+}
+
+
 typedef struct {
 	int max_group, curr_group;
 	int max_group_initialized;
@@ -137,6 +145,35 @@ avt_init( Handle self, PMenuItemReg m, AVTraverse * avt)
 	return false;
 }
 
+static void
+parse_options( HV * profile, PMenuItemReg r)
+{
+	dPROFILE;
+
+	if ( pexist( icon )) {
+		Handle c_object = pget_H(icon);
+		if ( c_object && register_image(c_object))
+			r-> icon = c_object;
+	}
+
+	if ( pexist( group ))
+		r-> group = pget_i(group);
+
+	if ( pexist( hint )) {
+		r-> hint = pget_sv(hint);
+		r-> hint = newSVsv(r->hint);
+	}
+
+	if ( pexist( onPaint )) {
+		r-> onPaint = pget_sv(onPaint);
+		r-> onPaint = newSVsv(r-> onPaint);
+	}
+	if ( pexist( onMeasure )) {
+		r-> onMeasure = pget_sv(onMeasure);
+		r-> onMeasure = newSVsv(r-> onMeasure);
+	}
+}
+
 void *
 AbstractMenu_new_menu( Handle self, SV * sv, int level, void * _avt)
 {
@@ -428,23 +465,10 @@ AbstractMenu_new_menu( Handle self, SV * sv, int level, void * _avt)
 				my-> dispose_menu( self, m);
 				return NULL;
 			}
-			if (!( SvOK( *holder) && SvROK( *holder) && SvTYPE( SvRV( *holder)) == SVt_PVHV)) {
+			if (!( SvOK( *holder) && SvROK( *holder) && SvTYPE( SvRV( *holder)) == SVt_PVHV))
 				warn("menu build error: options is not a hashref");
-			} else {
-				dPROFILE;
-				HV * profile = (HV*) SvRV(*holder);
-				if ( pexist( icon )) {
-					Handle c_object = pget_H(icon);
-					if ( register_image(c_object))
-						r-> icon = c_object;
-					pdelete(icon);
-				}
-				if ( pexist( group )) {
-					r-> group = pget_i(group);
-					pdelete(group);
-				}
-			}
-			r-> options = newSVsv( *holder);
+			else
+				parse_options( (HV*) SvRV(*holder), r);
 		}
 	}
 	return m;
@@ -502,6 +526,29 @@ AbstractMenu_set( Handle self, HV * profile)
 	if ( select) my-> set_selected( self, true);
 }
 
+static SV *
+new_options( PMenuItemReg m )
+{
+	HV * profile;
+	if (
+		m->group     == 0           &&
+		m->icon      == NULL_HANDLE &&
+		m->hint      == NULL        &&
+		m->onPaint   == NULL        &&
+		m->onMeasure == NULL
+	)
+		return NULL;
+
+	profile = newHV();
+	if ( m->group > 0 ) pset_i ( group,     m->group    );
+	if ( m->icon      ) pset_H ( icon,      m->icon     );
+	if ( m->hint      ) pset_sv( hint,      m->hint     );
+	if ( m->onMeasure ) pset_sv( onMeasure, m->onMeasure);
+	if ( m->onPaint   ) pset_sv( onPaint,   m->onPaint  );
+
+	return (SV*) profile;
+}
+
 static SV *
 new_av(  PMenuItemReg m, int level, Bool fullTree);
 
@@ -585,8 +632,11 @@ new_av_entry(  PMenuItemReg m, int level, Bool fullTree)
 			av_push( loc, newSVpv( "", 0));
 		}
 
-		if ( m-> options)
-			av_push( loc, newSVsv(m->options));
+		{
+			SV* options = new_options(m);
+			if ( options )
+				av_push( loc, newRV_noinc(options));
+		}
 	} else {
 		/* divider */
 		if ( m-> variable) {
@@ -756,7 +806,7 @@ AbstractMenu_set_items( Handle self, SV * items)
 	PMenuItemReg oldBranch = var-> tree;
 	if ( var-> stage > csFrozen) return;
 	var-> tree = ( PMenuItemReg) my-> new_menu( self, items, 0, NULL);
-	if ( var-> stage <= csNormal && var-> system)
+	if ( var-> stage == csNormal && var-> system)
 		apc_menu_update( self, oldBranch, var-> tree);
 	my-> dispose_menu( self, oldBranch);
 	notify( self, "<sss", "Change", "items", "");
@@ -816,7 +866,7 @@ AbstractMenu_accel( Handle self, Bool set, char * varName, SV * accel)
 	if ( m-> id > 0) {
 		if ( var-> stage <= csNormal && var-> system)
 			apc_menu_item_set_accel( self, m);
-		notify( self, "<ssUS", "Change", "accel", 
+		notify( self, "<ssUi", "Change", "accel",
 			m->variable ? m-> variable      : varName, 
 			m->variable ? m-> flags.utf8_variable : 0, 
 			accel);
@@ -832,7 +882,8 @@ AbstractMenu_action( Handle self, Bool set, char * varName, SV * action)
 	m = find_menuitem( self, varName, true);
 	if ( !m) return NULL_SV;
 	if ( !set) {
-		if ( m-> code)    return newSVsv( m-> code);
+		if ( m-> code)
+			return newSVsv( m-> code);
 		if ( m-> perlSub) {
 			SV * sv = newSVpv( m-> perlSub, 0);
 			if ( m-> flags. utf8_perlSub) SvUTF8_on( sv);
@@ -856,7 +907,8 @@ AbstractMenu_action( Handle self, Bool set, char * varName, SV * action)
 	} else {
 		char * line = ( char *) SvPV_nolen( action);
 		free( m-> perlSub);
-		if ( m-> code) sv_free( m-> code);
+		if ( m-> code)
+			sv_free( m-> code);
 		m-> code = NULL;
 		m-> perlSub = duplicate_string( line);
 		m-> flags. utf8_perlSub = prima_is_utf8_sv( action);
@@ -878,7 +930,7 @@ AbstractMenu_autoToggle( Handle self, Bool set, char * varName, Bool autotoggle)
 	if ( m-> id > 0) {
 		if ( var-> stage <= csNormal && var-> system)
 			apc_menu_item_set_autotoggle( self, m);
-		notify( self, "<ssUi", "Change", "autoToggle", 
+		notify( self, "<ssUi", "Change", "autoToggle",
 			m->variable ? m-> variable      : varName, 
 			m->variable ? m-> flags.utf8_variable : 0,
 			autotoggle);
@@ -938,13 +990,28 @@ AbstractMenu_group( Handle self, Bool set, char * varName, int group)
 	if ( !set) return m-> group;
 	if ( m-> group == group ) return group;
 	m-> group = group;
-	notify( self, "<ssUS", "Change", "group",
+	notify( self, "<ssUi", "Change", "group",
 		m->variable ? m-> variable      : varName,
 		m->variable ? m-> flags.utf8_variable : 0,
 		group);
 	return group;
 }
 
+SV*
+AbstractMenu_hint( Handle self, Bool set, char * varName, SV* hint)
+{
+	PMenuItemReg m;
+	if ( var-> stage > csFrozen) return 0;
+	m = find_menuitem( self, varName, true);
+	if ( m == NULL) return 0;
+	if ( !set) return m-> hint ? newSVsv(m->hint) : NULL_SV;
+	m-> hint = (hint && SvOK(hint)) ? newSVsv(hint) : NULL;
+	notify( self, "<ssUS", "Change", "hint",
+		m->variable ? m-> variable      : varName,
+		m->variable ? m-> flags.utf8_variable : 0,
+		m->hint ? m->hint : NULL_SV);
+	return m->hint;
+}
 
 Bool
 AbstractMenu_enabled( Handle self, Bool set, char * varName, Bool enabled)
@@ -961,7 +1028,7 @@ AbstractMenu_enabled( Handle self, Bool set, char * varName, Bool enabled)
 	if ( m-> id > 0) {
 		if ( var-> stage <= csNormal && var-> system)
 			apc_menu_item_set_enabled( self, m);
-		notify( self, "<ssUi", "Change", "enabled", 
+		notify( self, "<ssUi", "Change", "enabled",
 			m->variable ? m-> variable      : varName, 
 			m->variable ? m-> flags.utf8_variable : 0,
 			enabled);
@@ -984,11 +1051,8 @@ AbstractMenu_icon( Handle self, Bool set, char * varName, Handle icon)
 	}
 	if ( !register_image(icon))
 		return NULL_HANDLE;
-	if ( m-> icon ) {
-		if ( PObject( m-> icon)-> stage < csDead)
-			SvREFCNT_dec( SvRV(( PObject( m-> icon))-> mate));
-		unprotect_object( m-> icon);
-	}
+	if ( m-> icon )
+		unregister_image(m->icon);
 	m-> icon = icon;
 	if ( m-> id > 0) {
 		if ( var-> stage <= csNormal && var-> system)
@@ -1016,14 +1080,12 @@ AbstractMenu_image( Handle self, Bool set, char * varName, Handle image)
 	}
 	if ( !register_image(image))
 		return NULL_HANDLE;
-	if ( PObject( m-> bitmap)-> stage < csDead)
-		SvREFCNT_dec( SvRV(( PObject( m-> bitmap))-> mate));
-	unprotect_object( m-> bitmap);
+	unregister_image(m->bitmap);
 	m-> bitmap = image;
 	if ( m-> id > 0) {
 		if ( var-> stage <= csNormal && var-> system)
 			apc_menu_item_set_image( self, m);
-		notify( self, "<ssUH", "Change", "image", 
+		notify( self, "<ssUH", "Change", "image",
 			m->variable ? m-> variable      : varName, 
 			m->variable ? m-> flags.utf8_variable : 0,
 			image);
@@ -1034,52 +1096,45 @@ AbstractMenu_image( Handle self, Bool set, char * varName, Handle image)
 SV *
 AbstractMenu_options( Handle self, Bool set, char * varName, SV * options)
 {
-	HV * profile;
-	PMenuItemReg m;
+	MenuItemReg *m, n;
 	if ( var-> stage > csFrozen) return NULL_SV;
 	m = find_menuitem( self, varName, true);
 	if ( m == NULL) return NULL_SV;
 	if ( !set) {
-		HV * profile;
-		if ( m->options )
-			return newSVsv( m-> options);
-		profile = newHV();
-		if ( m-> icon )       pset_H(icon,  m->icon);
-		if ( m-> group != 0 ) pset_i(group, m->group);
-		return newRV_noinc((SV*)profile);
+		SV *options = new_options(m);
+		return options ? newRV(options) : NULL_SV;
 	}
 
-	if (!SvOK( SvRV( options))) {
-		sv_free( m-> options);
-		m-> options = NULL_SV;
+
+	if ( m-> flags. divider ) {
+		warn("Cannot set icon on a divider item");
+		return NULL_SV;
+	}
+
+	if ( !SvOK(options)) {
+		bzero(&n, sizeof(n));
 	} else {
-		dPROFILE;
 		if (!(SvROK( options) && SvTYPE( SvRV( options)) == SVt_PVHV)) {
 			warn("options is not a hashref");
 			return NULL_SV;
 		}
-		sv_free( m-> options);
-		m-> options = newSVsv( options);
-		profile = (HV*)SvRV(options);
-		if ( pexist(icon)) {
-			if ( m-> flags. divider )
-				warn("Cannot set icon on a divider item");
-			else
-				my->icon(self, true, varName, pget_H(icon));
-			pdelete(icon);
-		}
-		if ( pexist(group)) {
-			if ( m-> flags. divider )
-				warn("Cannot set group on a divider item");
-			else
-				my->group(self, true, varName, pget_i(group));
-			pdelete(icon);
-		}
+		n = *m;
+		parse_options( (HV*)SvRV(options), &n);
 	}
-	notify( self, "<ssUS", "Change", "options",
+
+	if ( n.icon != m->icon && m-> icon )
+		unregister_image(m->icon);
+	if ( n.hint != m->hint && m->hint )
+		sv_free(m->hint);
+	if ( n.onPaint != m->onPaint && m->onPaint )
+		sv_free(m->onPaint);
+	if ( n.onMeasure != m->onMeasure && m->onMeasure )
+		sv_free(m->onMeasure);
+	*m = n;
+
+	notify( self, "<ssU", "Change", "options",
 		m->variable ? m-> variable      : varName,
-		m->variable ? m-> flags.utf8_variable : 0,
-		options);
+		m->variable ? m-> flags.utf8_variable : 0);
 	return NULL_SV;
 }
 
@@ -1102,7 +1157,7 @@ AbstractMenu_submenu( Handle self, Bool set, char * varName, SV * submenu)
 	m-> down = ( PMenuItemReg) my-> new_menu( self, submenu, 1, NULL);
 	if ( var-> stage <= csNormal && var-> system)
 		apc_menu_update( self, m-> down, m-> down);
-	notify( self, "<ssU", "Change", "submenu", 
+	notify( self, "<ssU", "Change", "submenu",
 		m->variable ? m-> variable      : varName, 
 		m->variable ? m-> flags.utf8_variable : 0);
 
@@ -1129,7 +1184,7 @@ AbstractMenu_text( Handle self, Bool set, char * varName, SV * text)
 	if ( m-> id > 0) {
 		if ( var-> stage <= csNormal && var-> system)
 			apc_menu_item_set_text( self, m);
-		notify( self, "<ssUS", "Change", "text", 
+		notify( self, "<ssUs", "Change", "text",
 			m->variable ? m-> variable      : varName, 
 			m->variable ? m-> flags.utf8_variable : 0,
 			text);
@@ -1152,7 +1207,7 @@ AbstractMenu_key( Handle self, Bool set, char * varName, SV * key)
 	if ( m-> id > 0) {
 		if ( var-> stage <= csNormal && var-> system)
 			apc_menu_item_set_key( self, m);
-		notify( self, "<ssUi", "Change", "key", 
+		notify( self, "<ssUi", "Change", "key",
 			m->variable ? m-> variable      : varName, 
 			m->variable ? m-> flags.utf8_variable : 0,
 			m->key);
@@ -1168,8 +1223,8 @@ AbstractMenu_set_variable( Handle self, char * varName, SV * newName)
 	m = find_menuitem( self, varName, true);
 	if ( m == NULL) return;
 
-	notify( self, "<ssUS", "Change", "rename", 
-		m->variable ? m-> variable      : varName, 
+	notify( self, "<ssUS", "Change", "rename",
+		m->variable ? m-> variable      : varName,
 		m->variable ? m-> flags.utf8_variable : 0,
 		newName);
 
@@ -1331,7 +1386,7 @@ AbstractMenu_remove( Handle self, char * varName)
 	if ( prev) prev-> next = m-> next;
 	if ( m == var-> tree) var-> tree = m-> next;
 	m-> next = NULL;
-	notify( self, "<ssU", "Change", "remove", 
+	notify( self, "<ssU", "Change", "remove",
 			m->variable ? m-> variable      : varName, 
 			m->variable ? m-> flags.utf8_variable : 0);
 	my-> dispose_menu( self, m);
