@@ -3,27 +3,18 @@
 #include "Application.h"
 #include "Popup.h"
 #include "Widget.h"
+#include "private/Widget.h"
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#undef  my
-#define inherited CDrawable
-
 #define enter_method PWidget_vmt selfvmt = ((( PWidget) self)-> self)
+#undef my
 #define my  selfvmt
-#define var (( PWidget) self)
-
 #define evOK ( var-> evStack[ var-> evPtr - 1])
 #define objCheck if ( var-> stage > csNormal) return
 
-extern Bool Widget_size_notify( Handle self, Handle child, const Rect* metrix);
-extern Bool Widget_move_notify( Handle self, Handle child, Point * moveTo);
-extern void Widget_pack_slaves( Handle self);
-extern void Widget_place_slaves( Handle self);
-
-
 static Bool
 dnd_event_wanted(Handle self, PEvent event)
 {
@@ -389,6 +380,7 @@ SIZE_EVENT:;
 	}
 	Widget_pack_slaves( self);
 	Widget_place_slaves( self) ;
+	Widget_grid_slaves( self) ;
 }
 
 static Bool
