@@ -1,21 +1,12 @@
 #include "apricot.h"
 #include "guts.h"
 #include "Widget.h"
+#include "private/Widget.h"
 
 #ifdef __cplusplus
 extern "C" {
 #endif
 
-#undef  my
-#define inherited CDrawable
-#define my  ((( PWidget) self)-> self)
-#define var (( PWidget) self)
-#define his (( PWidget) child)
-
-void Widget_pack_slaves( Handle self);
-void Widget_place_slaves( Handle self);
-Bool Widget_size_notify( Handle self, Handle child, const Rect* metrix);
-Bool Widget_move_notify( Handle self, Handle child, Point * moveTo);
 static void Widget_pack_enter( Handle self);
 static void Widget_pack_leave( Handle self);
 static void Widget_place_enter( Handle self);
@@ -67,6 +58,9 @@ geometry_reset( Handle self, int geometry)
 
 	if ( geometry == gtPlace || geometry < 0)
 		Widget_place_slaves( self);
+
+	if ( geometry == gtGrid || geometry < 0)
+		Widget_grid_slaves( self);
 }
 
 int
@@ -91,6 +85,9 @@ Widget_geometry( Handle self, Bool set, int geometry)
 	case gtPack:
 		Widget_pack_leave( self);
 		break;
+	case gtGrid:
+		Widget_grid_leave( self);
+		break;
 	}
 	var-> geometry = geometry;
 	switch ( var-> geometry) {
@@ -104,6 +101,9 @@ Widget_geometry( Handle self, Bool set, int geometry)
 	case gtPack:
 		Widget_pack_enter( self);
 		break;
+	case gtGrid:
+		Widget_grid_enter( self);
+		break;
 	}
 	geometry_reset_all();
 	return var-> geometry;
@@ -159,57 +159,52 @@ Widget_reset_children_geometry( Handle self)
 {
 	Widget_pack_slaves( self);
 	Widget_place_slaves( self);
+	Widget_grid_slaves( self);
 }
 
-/* checks if Handle in is allowed to be a master for self -
-	used for gt::Pack */
-static Handle
-Widget_check_in( Handle self, Handle in, Bool barf)
+/* checks if Handle in is allowed to be a master for self */
+Handle
+Widget_check_in( Handle self, Handle in, int geometry)
 {
 	Handle h = in;
 
+	char * method =
+		(geometry == gtPack) ? "Prima::Widget::pack" :
+		((geometry == gtGrid) ? "Prima::Widget::grid" : "Prima::Widget::place");
+
 	/* check overall validity */
-	if ( !in || !kind_of( in, CWidget)) {
-		if ( barf)
-			croak("%s: invalid 'in': not a widget", "Prima::Widget::pack");
-		else
-			return NULL_HANDLE;
-	}
+	if ( !in || !kind_of( in, CWidget))
+		croak("%s: invalid 'in': not a widget", method);
 
 	/* check direct inheritance */
 	while ( h) {
-		if ( h == self) {
-			if ( barf)
-				croak("%s: invalid 'in': is already a child", "Prima::Widget::pack");
-			else
-				return NULL_HANDLE;
-		}
+		if ( h == self)
+			croak("%s: invalid 'in': is already a child", method);
 		h = PWidget( h)-> owner;
 	}
 
 	/* check slaves chain */
 	h = PWidget( in)-> packSlaves;
 	while ( h) {
-		if ( h == in) {
-			if ( barf)
-				croak("%s: invalid 'in': already a pack slave", "Prima::Widget::pack");
-			else
-				return NULL_HANDLE;
-		}
+		if ( h == in)
+			croak("%s: invalid 'in': already a pack slave", method);
 		h = PWidget( h)-> geomInfo. next;
 	}
 
 	h = PWidget( in)-> placeSlaves;
 	while ( h) {
-		if ( h == in) {
-			if ( barf)
-				croak("%s: invalid 'in': already a place slave", "Prima::Widget::pack");
-			else
-				return NULL_HANDLE;
-		}
+		if ( h == in)
+			croak("%s: invalid 'in': already a place slave", method);
 		h = PWidget( h)-> geomInfo. next;
 	}
 
+	if ( geometry != gtGrid && Widget_is_grid_slave(in, self))
+		croak("%s: invalid 'in': already in a grid", method);
+	if ( geometry == gtGrid && PWidget(in)->packSlaves)
+		croak("%s: cannot grid into a pack master", method);
+	if ( geometry == gtPack && Widget_has_grid_slaves(in))
+		croak("%s: cannot pack into a grid master", method);
+
 	/* place to check other chains if needed */
 
 	return in;
@@ -711,9 +706,12 @@ Widget_pack_enter( Handle self)
 	}
 	if ( var-> geomInfo. in) {
 		if ( hash_fetch( prima_guts.objects, &var-> geomInfo. in, sizeof(Handle)))
-			var-> geomInfo. in = Widget_check_in( self, var-> geomInfo. in, false);
+			var-> geomInfo. in = Widget_check_in( self, var-> geomInfo. in, gtPack);
 		else
-			var-> geomInfo. in = NULL_HANDLE;
+			croak("%s: bad in", "Prima::Widget::pack");
+	} else {
+		var-> geomInfo. in = NULL_HANDLE;
+		Widget_check_in( self, var-> owner, gtPack);
 	}
 
 	/* store into slaves list */
@@ -947,7 +945,7 @@ Widget_packInfo( Handle self, Bool set, SV * packInfo)
 			SV * sv = pget_sv( in);
 			in = NULL_HANDLE;
 			if ( SvOK( sv))
-				in = Widget_check_in( self, gimme_the_mate( sv), true);
+				in = Widget_check_in( self, gimme_the_mate( sv), gtPlace);
 			set_in = reset_zorder = true;
 		}
 
@@ -1002,9 +1000,12 @@ Widget_place_enter( Handle self)
 	/* see if leftover object references are alive */
 	if ( var-> geomInfo. in) {
 		if ( hash_fetch( prima_guts.objects, &var-> geomInfo. in, sizeof(Handle)))
-			var-> geomInfo. in = Widget_check_in( self, var-> geomInfo. in, false);
+			var-> geomInfo. in = Widget_check_in( self, var-> geomInfo. in, gtPlace);
 		else
-			var-> geomInfo. in = NULL_HANDLE;
+			croak("%s: bad in", "Prima::Widget::place");
+	} else {
+		var-> geomInfo. in = NULL_HANDLE;
+		Widget_check_in( self, var-> owner, gtPlace);
 	}
 
 	/* store into slaves list */
@@ -1299,7 +1300,7 @@ Widget_placeInfo( Handle self, Bool set, SV * placeInfo)
 			SV * sv = pget_sv( in);
 			in = NULL_HANDLE;
 			if ( SvOK(sv))
-				in = Widget_check_in( self, gimme_the_mate( sv), true);
+				in = Widget_check_in( self, gimme_the_mate( sv), gtPlace);
 			set_in = true;
 		}
 
@@ -1341,6 +1342,7 @@ XS( Widget_get_place_slaves_FROMPERL)
 void Widget_get_place_slaves          ( Handle self) { warn("Invalid call of Widget::get_place_slaves"); }
 void Widget_get_place_slaves_REDEFINED( Handle self) { warn("Invalid call of Widget::get_place_slaves"); }
 
+
 /*  */
 
 #ifdef __cplusplus
