@@ -28,7 +28,9 @@ my ($e, $ok) = Prima::Image::Exif->read_extras($i, tag_as_string => 1, load_thum
 die "Cannot read exif data in $ARGV[0]: $ok\n" unless $e;
 
 for my $k ( sort keys %$e ) {
-	if ( $k eq 'thumbnail' ) {
+	if ( $k eq 'XMP data') {
+		print "$k:\n==================\n$e->{$k}\n=====================\n";
+	} elsif ( $k eq 'thumbnail' ) {
 		my $i = $e->{$k};
 		if ( ! ref $i) {
 			print "** warning: thumbnail present but cannot be loaded: $e->{$k}\n";
