@@ -389,9 +389,10 @@ img_region_next_scanline(PRegionScanlineIterator i)
 #define SCAN_NEXT(i)  SCAN_PTR(i) = i->list[ SCAN_PTR(i) * 2 + 1 ]
 #define SCAN_CURR(i)  (i->region->boxes + SCAN_PTR(i))
 
-void
+Bool
 img_region_fill_scanline_map(PRegionScanlineIterator i, Byte *map, int map_offset, int map_width)
 {
+	Bool is_empty = true;
 	dSCAN_ITER(i);
 
 	bzero(map, map_width);
@@ -402,10 +403,14 @@ img_region_fill_scanline_map(PRegionScanlineIterator i, Byte *map, int map_offse
 		if ( l < map_width && r > 0 ) {
 			if ( l < 0 ) l = 0;
 			if ( r > map_width ) r = map_width + 1;
-			if ( r - l > 1 ) memset( map + l, 0xff, r - l - 1);
+			if ( r - l > 1 ) {
+				memset( map + l, 0xff, r - l - 1);
+				is_empty = false;
+			}
 		}
 		SCAN_NEXT(i);
 	}
+	return !is_empty;
 }
 
 static PRegionRec
@@ -996,8 +1001,10 @@ superimpose_outline( PRegionRec region, Point *pts, int count)
 			if (!( region = union_hline( region, scanline2box, a.x, a.y, b.x - a.x + 1)))
 				goto EXIT;
 		} else {
-			DEBUG("vertex %d.%d\n", a.x,a.y);
-			if (!( region = union_hline( region, scanline2box, a.x, a.y, 1)))
+			int n = (abs(a.x-b.x)+1) / (abs(a.y-b.y)+1);
+			if ( n < 1 ) n = 1;
+			DEBUG("vertex %d.%d %d\n", a.x,a.y, n);
+			if (!( region = union_hline( region, scanline2box, a.x, a.y, n)))
 				goto EXIT;
 		}
 	}
