@@ -1,32 +1,4 @@
 #! /usr/bin/perl -w
-#
-#  Copyright (c) 1997-2002 The Protein Laboratory, University of Copenhagen
-#  All rights reserved.
-#
-#  Redistribution and use in source and binary forms, with or without
-#  modification, are permitted provided that the following conditions
-#  are met:
-#  1. Redistributions of source code must retain the above copyright
-#     notice, this list of conditions and the following disclaimer.
-#  2. Redistributions in binary form must reproduce the above copyright
-#     notice, this list of conditions and the following disclaimer in the
-#     documentation and/or other materials provided with the distribution.
-#
-#  THIS SOFTWARE IS PROVIDED BY THE AUTHOR AND CONTRIBUTORS ``AS IS'' AND
-#  ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
-#  IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE
-#  ARE DISCLAIMED.  IN NO EVENT SHALL THE AUTHOR OR CONTRIBUTORS BE LIABLE
-#  FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL
-#  DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS
-#  OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION)
-#  HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT
-#  LIABILITY, OR TORT (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY
-#  OUT OF THE USE OF THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF
-#  SUCH DAMAGE.
-#
-#  $Id$
-#
-
 BEGIN {
 die <<UX if $^O !~ /win32|cygwin/i;
   This program is only intented to be run under MSWin32,
@@ -72,7 +44,7 @@ my $mswin32 = ($^O =~ /MSWin32/);
 my $cygwin = ($^O =~ /cygwin/);
 
 my $iarc = $Config{ installsitearch};
-my $ibin = $Config{ installbin};
+my $ibin = $Config{ installsitebin};
 my $perlpath = $Config{ perlpath};
 
 unless ( $cygwin) {
@@ -180,6 +152,9 @@ ENDP
 		}
 	}
 
+	print "Updating config ...\n";
+	system "perl Makefile.PL --postinstall dest=$iarc bin=$ibin";
+
 	if ( open F, "> install.log") {
 		print F "f:$_\n" for @instfiles;
 		print F "d:$_\n" for @instdir;
