@@ -67,6 +67,7 @@ prima_font_init_x11( char * error_buf)
 		prima_corefont_pp2font( do_default_font, &guts. default_font);
 		free( do_default_font);
 		do_default_font = NULL;
+		guts.skip_gtk_font |= SKIP_GTK_FONT_DEFAULT;
 	} else if ( !apc_fetch_resource( "Prima", "", "Font", "font",
 		NULL_HANDLE, frFont, &guts. default_font)) {
 		prima_fill_default_font( &guts. default_font);
@@ -91,6 +92,7 @@ prima_font_init_x11( char * error_buf)
 		prima_corefont_pp2font( do_menu_font, &guts. default_menu_font);
 		free( do_menu_font);
 		do_menu_font = NULL;
+		guts.skip_gtk_font |= SKIP_GTK_FONT_MENU;
 	} else if ( !apc_fetch_resource( "Prima", "", "Font", "menu_font",
 		NULL_HANDLE, frFont, &guts. default_menu_font)) {
 		memcpy( &guts. default_menu_font, &guts. default_font, sizeof( Font));
@@ -102,6 +104,7 @@ prima_font_init_x11( char * error_buf)
 		prima_corefont_pp2font( do_widget_font, &guts. default_widget_font);
 		free( do_widget_font);
 		do_widget_font = NULL;
+		guts.skip_gtk_font |= SKIP_GTK_FONT_WIDGET;
 	} else if ( !apc_fetch_resource( "Prima", "", "Font", "widget_font",
 		NULL_HANDLE, frFont, &guts. default_widget_font)) {
 		memcpy( &guts. default_widget_font, &guts. default_font, sizeof( Font));
@@ -109,10 +112,11 @@ prima_font_init_x11( char * error_buf)
 	Fdebug("widget font: %d.[w=%d,s=%g].%s.%s", DEBUG_FONT(guts.default_widget_font));
 
 	if ( do_msg_font) {
-		XrmPutStringResource( &guts.db, "Prima.message_font", do_widget_font);
+		XrmPutStringResource( &guts.db, "Prima.message_font", do_msg_font);
 		prima_corefont_pp2font( do_msg_font, &guts. default_msg_font);
 		free( do_msg_font);
 		do_msg_font = NULL;
+		guts.skip_gtk_font |= SKIP_GTK_FONT_MSG;
 	} else if ( !apc_fetch_resource( "Prima", "", "Font", "message_font",
 		NULL_HANDLE, frFont, &guts. default_msg_font)) {
 		memcpy( &guts. default_msg_font, &guts. default_font, sizeof( Font));
@@ -120,10 +124,11 @@ prima_font_init_x11( char * error_buf)
 	Fdebug("msg font: %d.[w=%d,s=%g].%s.%s", DEBUG_FONT(guts.default_msg_font));
 
 	if ( do_caption_font) {
-		XrmPutStringResource( &guts.db, "Prima.caption_font", do_widget_font);
+		XrmPutStringResource( &guts.db, "Prima.caption_font", do_caption_font);
 		prima_corefont_pp2font( do_caption_font, &guts. default_caption_font);
 		free( do_caption_font);
 		do_caption_font = NULL;
+		guts.skip_gtk_font |= SKIP_GTK_FONT_CAPTION;
 	} else if ( !apc_fetch_resource( "Prima", "", "Font", "caption_font",
 		NULL_HANDLE, frFont, &guts. default_caption_font)) {
 		memcpy( &guts. default_caption_font, &guts. default_font, sizeof( Font));
@@ -589,10 +594,9 @@ prima_font_pick( PFont source, Matrix matrix, PFont dest, unsigned int selection
 	if ( selection == 0 )
 		selection = FONTKEY_DEFAULT;
 
-	if ( dest != NULL )
-		Drawable_font_add( NULL_HANDLE, source, dest );
-	else
+	if ( dest == NULL )
 		dest = source;
+	Drawable_font_add( NULL_HANDLE, source, dest );
 
 #ifdef USE_FONTQUERY
 	if ( selection & FONTKEY_FREETYPE )
@@ -799,29 +803,64 @@ apc_gp_get_mapper_ranges(PFont font, int * count, unsigned int * flags)
 }
 
 Byte*
-apc_font_get_glyph_bitmap( Handle self, uint16_t index, unsigned int flags, PPoint offset, PPoint size, int *advance)
+apc_font_get_glyph_bitmap( Handle self, uint16_t index, unsigned int flags, PPoint offset, PPoint size, int *advance, int *bpp)
 {
+	*bpp = (flags & ggoMonochrome) ? 1 : 8;
+
 #ifdef USE_FONTQUERY
 	if ( is_opt(optInFontQuery) ) {
 		if ( X(self)->font)
-			return prima_fq_get_glyph_bitmap(self, index, flags, offset, size, advance);
+			return prima_fq_get_glyph_bitmap(self, index, flags, offset, size, advance, bpp);
 		return NULL;
 	}
 #endif
 
 #ifdef USE_XFT
 	if ( X(self)-> font-> xft)
-		return prima_xft_get_glyph_bitmap(self, index, flags, offset, size, advance);
+		return prima_xft_get_glyph_bitmap(self, index, flags, offset, size, advance, bpp);
 #endif
 
 	return prima_corefont_get_glyph_bitmap(self, index, flags & ggoMonochrome, offset, size, advance);
 }
 
+Bool
+apc_font_is_colored( Handle self)
+{
+	DEFXX;
+	PCachedFont f = XX->font;
+	if (
+		f->has_colors < 0 ||
+		( XT_IS_DBM(XX) && XT_IS_BITMAP(XX)) ||
+		( XT_IS_IMAGE(XX) && ((PImage)self)-> type == imBW )
+	)
+		return false;
+	else if ( f->has_colors > 0 )
+		return true;
+
+#ifdef USE_FONTQUERY
+	if ( is_opt(optInFontQuery) ) {
+		Bool ok = prima_ft_is_font_colored(X(self)->font->ft_face);
+		f->has_colors = ok ? 1 : -1;
+		return ok;
+	}
+#endif
+
+#ifdef USE_XFT
+	if ( f->xft ) {
+		Bool ok = prima_xft_is_font_colored(self);
+		f->has_colors = ok ? 1 : -1;
+		return ok;
+	}
+#endif
+
+	return false;
+}
+
 Bool
 apc_gp_set_text_matrix( Handle self, Matrix matrix)
 {
 	PFont f = & PDrawable(self)->font;
-	if (f->undef.height &&f->undef.size) /* too early */
+	if (f->undef.height && f->undef.size) /* too early */
 		return true;
 	return apc_gp_set_font( self, f);
 }
