@@ -469,7 +469,7 @@ prima_fq_get_text_width( Handle self, const char * text, int len, int flags, Poi
 }
 
 int
-prima_fq_get_glyphs_width( Handle self, PGlyphsOutRec t, Point * overhangs)
+prima_fq_get_glyphs_width( Handle self, PGlyphsOutRec t, int flags, Point * overhangs)
 {
 	DEFXX;
 	int i, ret = 0;
@@ -486,8 +486,8 @@ prima_fq_get_glyphs_width( Handle self, PGlyphsOutRec t, Point * overhangs)
 			continue;
 		g = fc.current->glyph;
 		ret += FT266_to_short(g->advance.x);
-		if ( (t->flags & toAddOverhangs ) || overhangs) {
-			UPDATE_OVERHANGS(t->len,t->flags)
+		if ( (flags & toAddOverhangs ) || overhangs) {
+			UPDATE_OVERHANGS(t->len,flags)
 		}
 	}
 	return ret;
@@ -505,7 +505,7 @@ Point *
 prima_fq_get_glyphs_box( Handle self, PGlyphsOutRec t)
 {
 	Point ovx;
-	int w = prima_fq_get_glyphs_width(self, t, &ovx);
+	int w = prima_fq_get_glyphs_width(self, t, toAddOverhangs, &ovx);
 	return prima_get_text_box(self, ovx, w);
 }
 
@@ -525,14 +525,15 @@ prima_fq_get_glyph_outline( Handle self, unsigned int index, unsigned int flags,
 }
 
 Byte*
-prima_fq_get_glyph_bitmap( Handle self, uint16_t index, unsigned int flags, PPoint offset, PPoint size, int *advance)
+prima_fq_get_glyph_bitmap( Handle self, uint16_t index, unsigned int flags, PPoint offset, PPoint size, int *advance, int *type)
 {
 	FT_Int32 ft_flags =
 		FT_LOAD_RENDER |
+		(( flags & ggoARGB     )   ? FT_LOAD_COLOR : 0)      |
 		(( flags & ggoUseHints )   ? 0 : FT_LOAD_NO_HINTING) |
 		(( flags & ggoMonochrome ) ? FT_LOAD_MONOCHROME : 0)
 		;
-	return prima_ft_get_glyph_bitmap(X(self)->font->ft_face, index, ft_flags, offset, size, advance);
+	return prima_ft_get_glyph_bitmap(X(self)->font->ft_face, index, ft_flags, offset, size, advance, type);
 }
 
 unsigned long *
